"""
    Security API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_ent.psm.model.api_list_meta import ApiListMeta
from pensando_ent.psm.model.security_ip_sec_policy import SecurityIPSecPolicy
globals()['ApiListMeta'] = ApiListMeta
globals()['SecurityIPSecPolicy'] = SecurityIPSecPolicy
from pensando_ent.psm.psm.model.security_ip_sec_policy_list import SecurityIPSecPolicyList


class TestSecurityIPSecPolicyList(unittest.TestCase):
    """SecurityIPSecPolicyList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSecurityIPSecPolicyList(self):
        """Test SecurityIPSecPolicyList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SecurityIPSecPolicyList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
