"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_ent.psm.model.network_auto_msg_lb_policy_watch_helper_watch_event import NetworkAutoMsgLbPolicyWatchHelperWatchEvent
globals()['NetworkAutoMsgLbPolicyWatchHelperWatchEvent'] = NetworkAutoMsgLbPolicyWatchHelperWatchEvent
from pensando_ent.psm.psm.model.network_auto_msg_lb_policy_watch_helper import NetworkAutoMsgLbPolicyWatchHelper


class TestNetworkAutoMsgLbPolicyWatchHelper(unittest.TestCase):
    """NetworkAutoMsgLbPolicyWatchHelper unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkAutoMsgLbPolicyWatchHelper(self):
        """Test NetworkAutoMsgLbPolicyWatchHelper"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkAutoMsgLbPolicyWatchHelper()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
