"""
    Aggwatch API reference

       # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_ent.psm.model.api_object_ref import ApiObjectRef
from pensando_ent.psm.model.api_status_result import ApiStatusResult
globals()['ApiObjectRef'] = ApiObjectRef
globals()['ApiStatusResult'] = ApiStatusResult
from pensando_ent.psm.psm.model.api_status import ApiStatus


class TestApiStatus(unittest.TestCase):
    """ApiStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testApiStatus(self):
        """Test ApiStatus"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ApiStatus()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
