"""
    Security API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_ent.psm.model.security_ip_sec_config import SecurityIPSecConfig
from pensando_ent.psm.model.security_ip_sec_policy_rule import SecurityIPSecPolicyRule
globals()['SecurityIPSecConfig'] = SecurityIPSecConfig
globals()['SecurityIPSecPolicyRule'] = SecurityIPSecPolicyRule
from pensando_ent.psm.psm.model.security_ip_sec_policy_spec import SecurityIPSecPolicySpec


class TestSecurityIPSecPolicySpec(unittest.TestCase):
    """SecurityIPSecPolicySpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSecurityIPSecPolicySpec(self):
        """Test SecurityIPSecPolicySpec"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SecurityIPSecPolicySpec()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
