"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_ent.psm.model.network_route_distinguisher import NetworkRouteDistinguisher
from pensando_ent.psm.model.security_propagation_status import SecurityPropagationStatus
globals()['NetworkRouteDistinguisher'] = NetworkRouteDistinguisher
globals()['SecurityPropagationStatus'] = SecurityPropagationStatus
from pensando_ent.psm.psm.model.network_virtual_router_status import NetworkVirtualRouterStatus


class TestNetworkVirtualRouterStatus(unittest.TestCase):
    """NetworkVirtualRouterStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkVirtualRouterStatus(self):
        """Test NetworkVirtualRouterStatus"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkVirtualRouterStatus()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
