"""
    Events API reference

    Service name    # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_ent.psm.psm.model.events_get_event_request import EventsGetEventRequest


class TestEventsGetEventRequest(unittest.TestCase):
    """EventsGetEventRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEventsGetEventRequest(self):
        """Test EventsGetEventRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = EventsGetEventRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
