"""
    Network API reference

       # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import psm
from pensando_ent.psm.model.network_virtual_router_peering_group import NetworkVirtualRouterPeeringGroup
globals()['NetworkVirtualRouterPeeringGroup'] = NetworkVirtualRouterPeeringGroup
from pensando_ent.psm.psm.model.network_auto_msg_virtual_router_peering_group_watch_helper_watch_event import NetworkAutoMsgVirtualRouterPeeringGroupWatchHelperWatchEvent


class TestNetworkAutoMsgVirtualRouterPeeringGroupWatchHelperWatchEvent(unittest.TestCase):
    """NetworkAutoMsgVirtualRouterPeeringGroupWatchHelperWatchEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNetworkAutoMsgVirtualRouterPeeringGroupWatchHelperWatchEvent(self):
        """Test NetworkAutoMsgVirtualRouterPeeringGroupWatchHelperWatchEvent"""
        # FIXME: construct object with mandatory attributes with example values
        # model = NetworkAutoMsgVirtualRouterPeeringGroupWatchHelperWatchEvent()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
